@@ -15,7 +15,7 @@ pub(crate) struct Connection {
 impl std::fmt::Debug for Connection {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("Connection")
-            .field("upstream", &self.upstream)
+            .field("upstream", &self.upstream.as_str())
             .field("client", &"Client")
             .finish()
     }
