@@ -144,7 +144,7 @@ pub struct State {
 impl std::fmt::Debug for State {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("State")
-            .field("upstream", &self.upstream)
+            .field("upstream", &self.upstream.as_str())
             .field("scope", &self.scope)
             .field("store", &self.store)
             .field("db", &"Db")
@@ -563,7 +563,7 @@ impl MoveEntryPath {
     }
 }
 
-#[tracing::instrument(name = "Upload image", skip(pl))]
+#[tracing::instrument(name = "Upload image", skip(req, pl))]
 async fn upload(
     req: HttpRequest,
     pl: web::Payload,
@@ -612,7 +612,7 @@ struct ImagePath {
     filename: String,
 }
 
-#[tracing::instrument(name = "Serve image")]
+#[tracing::instrument(name = "Serve image", skip(req))]
 async fn image(
     req: HttpRequest,
     path: web::Path<ImagePath>,
@@ -632,7 +632,7 @@ struct ThumbnailQuery {
     size: u16,
 }
 
-#[tracing::instrument(name = "Serve thumbnail")]
+#[tracing::instrument(name = "Serve thumbnail", skip(req))]
 async fn thumbnail(
     req: HttpRequest,
     path: web::Path<ThumbnailPath>,
@@ -652,7 +652,7 @@ async fn index(state: web::Data<State>) -> Result<HttpResponse, StateError> {
     .stateful(&state)
 }
 
-#[tracing::instrument(name = "Collection")]
+#[tracing::instrument(name = "Collection", skip(req))]
 async fn collection(
     path: web::Path<CollectionPath>,
     token: Option<ValidToken>,
